diff --git a/fusion-ie9-fixes-1273788-6.patch b/fusion-ie9-fixes-1273788-6.patch
new file mode 100644
index 0000000..e69de29
--- /dev/null
+++ b/fusion-ie9-fixes-1273788-6.patch
diff --git a/fusion_core/css/ie9-fixes.css b/fusion_core/css/ie9-fixes.css
new file mode 100644
index 0000000..72afd40
--- /dev/null
+++ b/fusion_core/css/ie9-fixes.css
@@ -0,0 +1,9 @@
+
+/* IE9 fixes
+-------------------------------------------------------------- */
+
+/* grid mask overlay opacity fix
+-------------------------------------------------------------- */
+#grid-mask-overlay {
+  -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=75)";
+}
diff --git a/fusion_core/page.tpl.php b/fusion_core/page.tpl.php
index 763f432..fa8be2d 100644
--- a/fusion_core/page.tpl.php
+++ b/fusion_core/page.tpl.php
@@ -7,6 +7,9 @@
   <?php print $head; ?>
   <?php print $styles; ?>
   <?php print $setting_styles; ?>
+  <!--[if IE 9]>
+  <?php print $ie9_styles; ?>
+  <![endif]-->
   <!--[if IE 8]>
   <?php print $ie8_styles; ?>
   <![endif]-->
diff --git a/fusion_core/template.php b/fusion_core/template.php
index 2cb608a..709278c 100644
--- a/fusion_core/template.php
+++ b/fusion_core/template.php
@@ -102,10 +102,10 @@
     $vars['breadcrumb'] = '';
   }
 
   // Add grid, color, ie6, ie7, ie8 & local stylesheets, including inherited & rtl versions
   $grid_style = '/css/' . theme_get_setting('theme_grid');
   $themes = fusion_core_theme_paths($theme_key);
-  $vars['setting_styles'] = $vars['ie6_styles'] = $vars['ie7_styles'] = $vars['ie8_styles'] = $vars['local_styles'] = '';
+  $vars['setting_styles'] = $vars['ie6_styles'] = $vars['ie7_styles'] = $vars['ie8_styles'] = $vars['ie9_styles'] = $vars['local_styles'] = '';
   $query_string = '?'. substr(variable_get('css_js_query_string', '0'), 0, 1);
   foreach ($themes as $name => $path) {
     $link = '<link type="text/css" rel="stylesheet" media="all" href="' . base_path() . $path;
@@ -113,12 +113,14 @@
     $vars['ie6_styles'] .= (file_exists($path . '/css/ie6-fixes.css')) ? $link . '/css/ie6-fixes.css' . $query_string . '"/>' . "\n" : '';
     $vars['ie7_styles'] .= (file_exists($path . '/css/ie7-fixes.css')) ? $link . '/css/ie7-fixes.css' . $query_string . '" />' . "\n" : '';
     $vars['ie8_styles'] .= (file_exists($path . '/css/ie8-fixes.css')) ? $link . '/css/ie8-fixes.css' . $query_string . '" />' . "\n" : '';
+    $vars['ie9_styles'] .= (file_exists($path . '/css/ie9-fixes.css')) ? $link . '/css/ie9-fixes.css' . $query_string . '" />' . "\n" : '';
     $vars['local_styles'] .= (file_exists($path . '/css/local.css')) ? $link . '/css/local.css' . $query_string . '" />' . "\n" : '';
     if (defined('LANGUAGE_RTL') && $language->direction == LANGUAGE_RTL) {
       $vars['setting_styles'] .= (file_exists($path . $grid_style . '-rtl.css')) ? $link . $grid_style . '-rtl.css" />' . "\n" : '';
       $vars['ie6_styles'] .= (file_exists($path . '/css/ie6-fixes-rtl.css')) ? $link . '/css/ie6-fixes-rtl.css' . $query_string . '" />' . "\n" : '';
       $vars['ie7_styles'] .= (file_exists($path . '/css/ie7-fixes-rtl.css')) ? $link . '/css/ie7-fixes-rtl.css' . $query_string . '" />' . "\n" : '';
       $vars['ie8_styles'] .= (file_exists($path . '/css/ie8-fixes-rtl.css')) ? $link . '/css/ie8-fixes-rtl.css' . $query_string . '" />' . "\n" : '';
+      $vars['ie9_styles'] .= (file_exists($path . '/css/ie9-fixes-rtl.css')) ? $link . '/css/ie9-fixes-rtl.css' . $query_string . '" />' . "\n" : '';
       $vars['local_styles'] .= (file_exists($path . '/css/local-rtl.css')) ? $link . '/css/local-rtl.css' . $query_string . '" />' . "\n" : '';
     }
   }
@@ -102,10 +102,10 @@
   }
 
-  // Add grid, color, ie6, ie7, ie8 & local stylesheets, including inherited & rtl versions
+  // Add grid, color, ie6, ie7, ie8, ie9 & local stylesheets, including inherited & rtl versions
   $grid_style = '/css/' . theme_get_setting('theme_grid');
   $themes = fusion_core_theme_paths($theme_key);
